==> wangxiaolu-sfa-ui-v1.0.0.zip: wangxiaolu-sfa-ui-v1.0.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [1.0.0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.2...v1.0.0) (2025-07-31)

### [0.1.2](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.1...v0.1.2) (2025-07-31)


### 💄 Styles | 样式调整

* **table:** 修复：表格加载蒙层覆盖到其他蒙层的问题 ([d674c8f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/d674c8fac56374ba3b334b858da856e67afbc44b))


### ✨ Features | 新增功能

* **jimureport:** 新增：积木报表设计页面_自己实现（完成页面布局） ([f3e1cd1](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/f3e1cd124496ceba993108d0e4362f45ebe9e5cc))
* **login:** 新增：登录状态过期自动续签 ([75a30ce](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/75a30ce60bb1b79019f246f0f9cc33532b562bee))
* **other/logistics:** 新增：物流信息查询页面 ([55e0116](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/55e01167b2d2148cdc6897562ef637973c3ab78c))
* **promotion:** 新增：促销计划把促销员薪资和杂费改为是否有促销台和活动品项，新增促销员午休开始和结束时间 ([10478ca](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/10478ca2b5a28f66d8ad9ff93c3508a719abf377))
* **promotion:** 新增：促销计划把促销员薪资和杂费改为是否有促销台和活动品项，新增促销员午休开始和结束时间 ([2d71eb3](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/2d71eb3c1b12a2ef8a300a323f29c24cdad1fee6))
* **report:** 新增_管理员分配报表权限给个人功能_个人查看被分配报表列表和预览功能 ([be545bf](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/be545bf7644d6572dd6a5007bd80e23bd0cbf65b))
* **report:** 新增：积木报表自定义报表设计页面 ([dbfebf4](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/dbfebf45632b734923c7d67f026bdf14152552ed))


### 💄 Styles | 功能调整

* **.versionrc:** 调整：版本更新标题说明字段 ([52a5b82](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/52a5b8257ca71eb7b4baf6b91492707c8fe7ace3))
* **api/logistics:** 修改：查询物流轨迹的接口地址去掉 order 路径 ([9a0deb7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9a0deb765e23911b9fc0e8041b938b9d45cec121))
* **api/logistics:** 修改：物流查询接口不会走校验登录身份 ([2a38732](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/2a387321006c6368f5b329ab19b1da733d090d71))
* **bi:** 修改：报表查询自己被分配的数据接口调整 ([337dcd0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/337dcd0cb648230833dd27a6b590216a1328bb2b))
* **logistics:** 修改：合同单号改成订单号（DD 单号） ([9cf0f0b](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9cf0f0be5d00fbd28a613ee3690cf3ef4311a6f7))
* **promotion:** 修改：促销计划新增或修改计划模版表格下载地址更改为最新 ([ddd1d16](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/ddd1d165b3f201fc7557e60ca5f6847a9f634686))
* **promotion:** 修改：促销计划中，新增和变更时弹框中去掉促销员工资和杂费，改为是否有促销台和活动品项，并增加午休开始和结束时间（PC 端完成） ([09774b7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/09774b71f5548b502a7a40a3aca1ef2d11869c11))
* **promotion:** 修改：促销计划中，新增和变更时弹框中去掉促销员工资和杂费，改为是否有促销台和活动品项，并增加午休开始和结束时间（PC 端完成） ([e5863d0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/e5863d04be505509dd44de1b1a07597af39c8cd1))
* **promotion:** 修改：促销计划中新增修改计划上传时如果没有错误信息，则不显示错误信息列 ([81e4694](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/81e469471358360ef82508c00b71fb0114f4a300))
* **promotion:** 修改：促销计划中新增修改计划上传时如果没有错误信息，则不显示错误信息列 ([6dd85bc](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/6dd85bc320ec202c18ce5dd32248db161e83d36c))
* **promotion:** 修改：上传计划时午休上下班时间格式修正 ([b3d55d6](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/b3d55d641b60b6d175c06468ee85c01c67c88a1a))
* **promotion:** 修改：新增或修改计划模版升级为 4.0 版本 ([901b75d](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/901b75de331e6e508781b5a83513c0e23cf509f0))
* **report/manager:** 修改：积木报表分配权限搭建 UI 效果 ([765a6be](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/765a6bede0aea74590bacf8e70b123e115649ef2))
* **report:** 修改：查看分配列表 ([9538d21](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9538d21370692ffe1c02a0dfa3c1d9a2bbebd1d7))
* **request:** 修改：版本更新通知效果 ([39c386d](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/39c386da77fef39208262a58f85e9ba3d349207b))
* **version:** 修改：暂时隐藏版本提示效果 ([eff146b](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/eff146bf1d4f0067dea1708e759a1603498fdc13))
* **wuliu:** 修改：物流查询接口字段变化 ([502081f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/502081f2a7cf7b8133789be309c6dc369e4f8eaa))


### 🐛 Bug Fixes | 问题修复

* **permission.js:** 修改：物流查询页面暂时无需登录即可 ([78ef848](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/78ef8485c5de2cbef4fc1f1b61acbeac9af0d954))
* **promotion/task:** 修复：促销任务删除打卡记录报错问题 ([ea09ac3](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/ea09ac393cd779460c6820041c0dde1d317617dc))
* **promotion:** 解决：重置新增表单时，部分报错问题 ([5dca2f7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/5dca2f78dfc61854a3ec5ffbab3fe96ba36d5079))
* **promotion:** 修复：PC 端新增编辑促销计划时间秒数应该置为 0 ([702d82f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/702d82fe7dde9800a537f32f20096aedd2efb401))
* **report:** 合并代码：把报表设计功能完成并合并准备上线 ([f7efedb](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/f7efedb1bc71a17a14b0a04055247ea86987b968))
* **report:** 修改：积木报表新增和编辑页面_路径报错修改 ([92a74cf](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/92a74cf06bdb793bd93e2ecea02c97a56f4ac3d6))
* **vite.config.js:** 修改：登录页面样式变为移动端样式的问题 ([3385268](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/338526811487b8155fe4fd1e19f0057627d6fe59))

### [0.1.1](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.0...v0.1.1) (2025-07-11)


### 💄 Styles | 结构重构

* **updateversion:** 取消打印语句 ([28887e8](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/28887e89a3f61a6548867e113f7a150f1d34b4ac))

###

==> wangxiaolu-sfa-ui-v1.1.0.zip: wangxiaolu-sfa-ui-v1.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

## [1.1.0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v1.0.0...v1.1.0) (2025-08-11)


### 📝 Documentation | 文档更新

* **version:** 新增：版本更新说明效果 ([10dbcbf](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/10dbcbfe3265b867d8d437d2937eb38dfa8add2f))


### 💄 Styles | 功能调整

* **updateversion:** 修改：版本更新保存接口确定并使用 ([3932a49](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/3932a4990cf33e9dd391f2e7cd9da1ab808f62a8))


### ✨ Features | 新增功能

* **promotion:** 新增：促销管理-促销任务，增加活动品项列 ([950970e](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/950970e0e8c659dbc61a4c6ff73a2485d8b5178e))

## [1.0.0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.2...v1.0.0) (2025-07-31)


### 💄 Styles | 样式调整

* **table:** 修复：表格加载蒙层覆盖到其他蒙层的问题 ([d674c8f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/d674c8fac56374ba3b334b858da856e67afbc44b))


### ✨ Features | 新增功能

* **jimureport:** 新增：积木报表设计页面_自己实现（完成页面布局） ([f3e1cd1](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/f3e1cd124496ceba993108d0e4362f45ebe9e5cc))
* **login:** 新增：登录状态过期自动续签 ([75a30ce](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/75a30ce60bb1b79019f246f0f9cc33532b562bee))
* **other/logistics:** 新增：物流信息查询页面 ([55e0116](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/55e01167b2d2148cdc6897562ef637973c3ab78c))
* **promotion:** 新增：促销计划把促销员薪资和杂费改为是否有促销台和活动品项，新增促销员午休开始和结束时间 ([10478ca](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/10478ca2b5a28f66d8ad9ff93c3508a719abf377))
* **promotion:** 新增：促销计划把促销员薪资和杂费改为是否有促销台和活动品项，新增促销员午休开始和结束时间 ([2d71eb3](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/2d71eb3c1b12a2ef8a300a323f29c24cdad1fee6))
* **report:** 新增_管理员分配报表权限给个人功能_个人查看被分配报表列表和预览功能 ([be545bf](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/be545bf7644d6572dd6a5007bd80e23bd0cbf65b))
* **report:** 新增：积木报表自定义报表设计页面 ([dbfebf4](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/dbfebf45632b734923c7d67f026bdf14152552ed))


### 💄 Styles | 功能调整

* **.versionrc:** 调整：版本更新标题说明字段 ([52a5b82](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/52a5b8257ca71eb7b4baf6b91492707c8fe7ace3))
* **api/logistics:** 修改：查询物流轨迹的接口地址去掉 order 路径 ([9a0deb7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9a0deb765e23911b9fc0e8041b938b9d45cec121))
* **api/logistics:** 修改：物流查询接口不会走校验登录身份 ([2a38732](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/2a387321006c6368f5b329ab19b1da733d090d71))
* **bi:** 修改：报表查询自己被分配的数据接口调整 ([337dcd0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/337dcd0cb648230833dd27a6b590216a1328bb2b))
* **logistics:** 修改：合同单号改成订单号（DD 单号） ([9cf0f0b](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9cf0f0be5d00fbd28a613ee3690cf3ef4311a6f7))
* **promotion:** 修改：促销计划新增或修改计划模版表格下载地址更改为最新 ([ddd1d16](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/ddd1d165b3f201fc7557e60ca5f6847a9f634686))
* **promotion:** 修改：促销计划中，新增和变更时弹框中去掉促销员工资和杂费，改为是否有促销台和活动品项，并增加午休开始和结束时间（PC 端完成） ([09774b7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/09774b71f5548b502a7a40a3aca1ef2d11869c11))
* **promotion:** 修改：促销计划中，新增和变更时弹框中去掉促销员工资和杂费，改为是否有促销台和活动品项，并增加午休开始和结束时间（PC 端完成） ([e5863d0](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/e5863d04be505509dd44de1b1a07597af39c8cd1))
* **promotion:** 修改：促销计划中新增修改计划上传时如果没有错误信息，则不显示错误信息列 ([81e4694](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/81e469471358360ef82508c00b71fb0114f4a300))
* **promotion:** 修改：促销计划中新增修改计划上传时如果没有错误信息，则不显示错误信息列 ([6dd85bc](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/6dd85bc320ec202c18ce5dd32248db161e83d36c))
* **promotion:** 修改：上传计划时午休上下班时间格式修正 ([b3d55d6](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/b3d55d641b60b6d175c06468ee85c01c67c88a1a))
* **promotion:** 修改：新增或修改计划模版升级为 4.0 版本 ([901b75d](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/901b75de331e6e508781b5a83513c0e23cf509f0))
* **report/manager:** 修改：积木报表分配权限搭建 UI 效果 ([765a6be](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/765a6bede0aea74590bacf8e70b123e115649ef2))
* **report:** 修改：查看分配列表 ([9538d21](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/9538d21370692ffe1c02a0dfa3c1d9a2bbebd1d7))
* **request:** 修改：版本更新通知效果 ([39c386d](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/39c386da77fef39208262a58f85e9ba3d349207b))
* **version:** 修改：暂时隐藏版本提示效果 ([eff146b](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/eff146bf1d4f0067dea1708e759a1603498fdc13))
* **wuliu:** 修改：物流查询接口字段变化 ([502081f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/502081f2a7cf7b8133789be309c6dc369e4f8eaa))


### 🐛 Bug Fixes | 问题修复

* **permission.js:** 修改：物流查询页面暂时无需登录即可 ([78ef848](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/78ef8485c5de2cbef4fc1f1b61acbeac9af0d954))
* **promotion/task:** 修复：促销任务删除打卡记录报错问题 ([ea09ac3](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/ea09ac393cd779460c6820041c0dde1d317617dc))
* **promotion:** 解决：重置新增表单时，部分报错问题 ([5dca2f7](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/5dca2f78dfc61854a3ec5ffbab3fe96ba36d5079))
* **promotion:** 修复：PC 端新增编辑促销计划时间秒数应该置为 0 ([702d82f](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/702d82fe7dde9800a537f32f20096aedd2efb401))
* **report:** 合并代码：把报表设计功能完成并合并准备上线 ([f7efedb](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/f7efedb1bc71a17a14b0a04055247ea86987b968))
* **report:** 修改：积木报表新增和编辑页面_路径报错修改 ([92a74cf](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/92a74cf06bdb793bd93e2ecea02c97a56f4ac3d6))
* **vite.config.js:** 修改：登录页面样式变为移动端样式的问题 ([3385268](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/338526811487b8155fe4fd1e19f0057627d6fe59))

### [0.1.2](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.1...v0.1.2) (2025-07-31)

### [0.1.1](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/compare/v0.1.0...v0.1.1) (2025-07-11)


### 💄 Styles | 结构重构

* **updateversion:** 取消打印语句 ([28887e8](http://192.168.100.51/sfa/wangxiaolu-sfa-ui/commit/28887e89a3f61a6548867e113f7a150f1d34b4ac))

###
